
# `nionctl`

An abbreviation of common linux command-line utilities into one ctl


## Installation

Install `nionctl` with pip:

```bash
pip install nionctl
```
The PyPi page is availible [here.](https://pypi.org/project/nionctl/)


## Current commands (WIP):

- Basic WiFi controlling (uses `nmcli`)
- Basic Bluetooth controlling (uses `bluetoothctl`)
- `git clone` from url to default directory
- `neofetch` (because why not)

Full docs are available [at COMMANDS.md](COMMANDS.md)


## Contributing

Any kinds of contributions are very welcome!
Currently the main goals are to bring more utilities and make the ctl cross-platform. Any tests on other linux distros are also welcome!

